package Net::Netflix;

use warnings;
use strict;

=head1 NAME

Net::Netflix - Please see updated module at WWW::Netflix.

=head1 VERSION

Version 0.05

=cut

our $VERSION = '0.05';


=head1 SYNOPSIS

This module has moved to WWW::Netflix. Please download the updated 
module from the new namespace.

=cut

die "\n ** This module has moved to WWW::Netflix.              **",
    "\n ** Please download and install WWW::Netflix from CPAN. ** \n\n";

=head1 AUTHOR

Christie Robertson and Colin Meyer, C<< <pants at helvella.org> >>

=cut

1; # End of Net::Netflix
